@@ -1,4 +1,4 @@
-/* Copyright (c) 2000-2009 Wolfgang Hoermann and Josef Leydold */
+/* Copyright (c) 2000-2010 Wolfgang Hoermann and Josef Leydold */
 /* Department of Statistics and Mathematics, WU Wien, Austria  */
 
 #include <unur_source.h>
@@ -14,9 +14,4 @@ _unur_sf_bessel_k_expo(double x, double nu)
 {
   return bessel_k( x, nu, 2);
 } 
-#else
-double _unur_sf_bessel_k(double x ATTRIBUTE__UNUSED, double nu ATTRIBUTE__UNUSED) 
-{ 
-  return 0./0.; 
-}
 #endif 
