@@ -95,3 +95,7 @@ rm(adv.vnrou.norm)
 unur.test.statistic()
 
 ## -- End -------------------------------------------------------------------
+
+detach("package:Runuran",unload = TRUE)
+
+## --------------------------------------------------------------------------
